@@ -52,10 +52,10 @@ int Create(char *mddev, int mdfd,
 	 * if runstop==run, or raiddisks diskswere used,
 	 * RUN_ARRAY
 	 */
-	int minsize, maxsize;
+	int minsize=0, maxsize=0;
 	char *mindisc = NULL;
 	char *maxdisc = NULL;
-	int i;
+	int dnum;
 	mddev_dev_t dv;
 	int fail=0, warn=0;
 	struct stat stb;
@@ -77,22 +77,22 @@ int Create(char *mddev, int mdfd,
 	}
 	if (raiddisks < 1) {
 		fprintf(stderr,
-			Name ": a number of --raid-disks must be given to create an array\n");
+			Name ": a number of --raid-devices must be given to create an array\n");
 		return 1;
 	}
 	if (raiddisks < 2 && level >= 4) {
 		fprintf(stderr,
-			Name ": atleast 2 raid-disks needed for level 4 or 5\n");
+			Name ": atleast 2 raid-devices needed for level 4 or 5\n");
 		return 1;
 	}
 	if (raiddisks+sparedisks > MD_SB_DISKS) {
 		fprintf(stderr,
-			Name ": too many discs requested: %d+%d > %d\n",
+			Name ": too many devices requested: %d+%d > %d\n",
 			raiddisks, sparedisks, MD_SB_DISKS);
 		return 1;
 	}
 	if (subdevs > raiddisks+sparedisks) {
-		fprintf(stderr, Name ": You have listed more disks (%d) than are in the array(%d)!\n", subdevs, raiddisks+sparedisks);
+		fprintf(stderr, Name ": You have listed more devices (%d) than are in the array(%d)!\n", subdevs, raiddisks+sparedisks);
 		return 1;
 	}
 	if (subdevs < raiddisks+sparedisks) {
@@ -123,18 +123,19 @@ int Create(char *mddev, int mdfd,
 	/* now look at the subdevs */
 	array.active_disks = 0;
 	array.working_disks = 0;
-	for (dv=devlist; dv; dv=dv->next) {
+	dnum = 0;
+	for (dv=devlist; dv; dv=dv->next, dnum++) {
 		char *dname = dv->devname;
 		int dsize, freesize;
 		int fd;
 		if (strcasecmp(dname, "missing")==0) {
-			if (first_missing > i)
-				first_missing = i;
+			if (first_missing > dnum)
+				first_missing = dnum;
 			missing_disks ++;
 			continue;
 		}
 		array.working_disks++;
-		if (i < raiddisks)
+		if (dnum < raiddisks)
 			array.active_disks++;
 		fd = open(dname, O_RDONLY, 0);
 		if (fd <0 ) {
@@ -193,8 +194,8 @@ int Create(char *mddev, int mdfd,
 		if (verbose && level>0)
 			fprintf(stderr, Name ": size set to %dK\n", size);
 	}
-	if ((maxsize-size)*100 > maxsize) {
-		fprintf(stderr, Name ": largest drive (%s) exceed size (%dK) by more than 1%\n",
+	if (level >= 1 && ((maxsize-size)*100 > maxsize)) {
+		fprintf(stderr, Name ": largest drive (%s) exceed size (%dK) by more than 1%%\n",
 			maxdisc, size);
 		warn = 1;
 	}
@@ -269,13 +270,13 @@ int Create(char *mddev, int mdfd,
 		return 1;
 	}
 	
-	for (i=0, dv = devlist ; dv ; dv=dv->next, i++) {
+	for (dnum=0, dv = devlist ; dv ; dv=dv->next, dnum++) {
 		int fd;
 		struct stat stb;
 		mdu_disk_info_t disk;
 
-		disk.number = i;
-		if (i >= insert_point)
+		disk.number = dnum;
+		if (dnum >= insert_point)
 			disk.number++;
 		disk.raid_disk = disk.number;
 		if (disk.raid_disk < raiddisks)
@@ -324,7 +325,7 @@ int Create(char *mddev, int mdfd,
 		}
 		fprintf(stderr, Name ": array %s started.\n", mddev);
 	} else {
-		fprintf(stderr, Name ": not starting array - not enough discs.\n");
+		fprintf(stderr, Name ": not starting array - not enough devices.\n");
 	}
 	return 0;
 }
